#!/bin/bash

# Define variables
PANEL_NAME="AffPanel"
PANEL_DIR="/opt/affpanel"
PANEL_PORT="3333"
APACHE_CONF="/etc/apache2/sites-available/affpanel.conf"
DB_FILE="$PANEL_DIR/users.db"

# Function to install required packages
install_dependencies() {
    echo "📦 Installing Apache, PHP, SQLite, and Bind9 DNS..."
    apt update -y
    apt install -y apache2 php-cli php-fpm php-sqlite3 sqlite3 unzip libapache2-mod-php bind9
}

# Function to setup authentication
setup_authentication() {
    echo "🔑 Setting up authentication for AffPanel..."
    read -p "Enter admin username: " ADMIN_USER
    read -s -p "Enter admin password: " ADMIN_PASS
    echo ""

    mkdir -p "$PANEL_DIR"
    sqlite3 "$DB_FILE" "CREATE TABLE IF NOT EXISTS users (id INTEGER PRIMARY KEY, username TEXT, password TEXT);"
    HASHED_PASS=$(php -r "echo password_hash('$ADMIN_PASS', PASSWORD_BCRYPT);")
    sqlite3 "$DB_FILE" "INSERT INTO users (username, password) VALUES ('$ADMIN_USER', '$HASHED_PASS');"
}

# Function to create AffPanel dashboard and management tools
setup_panel() {
    echo "📝 Setting up AffPanel..."
    mkdir -p "$PANEL_DIR"

    # Create index.php (Dashboard)
    cat <<EOF > "$PANEL_DIR/index.php"
<?php
session_start();
if (!isset(\$_SESSION["authenticated"])) {
    header("Location: login.php");
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>AffPanel Dashboard</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body { display: flex; min-height: 100vh; overflow-x: hidden; }
        .sidebar { width: 250px; background: #343a40; color: white; padding-top: 20px; height: 100vh; position: fixed; }
        .sidebar a { color: white; text-decoration: none; padding: 10px 20px; display: block; }
        .sidebar a:hover { background: #495057; }
        .content { margin-left: 250px; padding: 20px; width: 100%; }
        .stats-card { border: 1px solid #ddd; padding: 20px; border-radius: 5px; text-align: center; background: #fff; }
    </style>
</head>
<body>

<div class="sidebar">
    <h3 class="text-center">AffPanel</h3>
    <a href="index.php">🏠 Dashboard</a>
    <a href="domains.php">🌐 Domain Management</a>
    <a href="dns.php">📡 DNS Management</a>
    <a href="logout.php" style="color: #dc3545;">🚪 Logout</a>
</div>

<div class="content">
    <h2>Welcome to AffPanel</h2>
    <p>Manage your websites, domains, and DNS settings easily.</p>

    <div class="row">
        <div class="col-md-4">
            <div class="stats-card"><h4>🌍 Total Domains</h4>
                <p><?php echo trim(shell_exec("ls /etc/apache2/sites-available | grep '.conf' | wc -l")); ?></p>
            </div>
        </div>
        <div class="col-md-4">
            <div class="stats-card"><h4>📡 Total DNS Records</h4>
                <p><?php echo trim(shell_exec("ls /etc/bind/ | grep '^db.' | wc -l")); ?></p>
            </div>
        </div>
        <div class="col-md-4">
            <div class="stats-card"><h4>🖥️ Server Uptime</h4>
                <p><?php echo trim(shell_exec("uptime -p")); ?></p>
            </div>
        </div>
    </div>
</div>

</body>
</html>
EOF

    # Create domains.php
    cat <<EOF > "$PANEL_DIR/domains.php"
<?php
session_start();
if (!isset(\$_SESSION["authenticated"])) {
    header("Location: login.php");
    exit();
}

if (\$_SERVER["REQUEST_METHOD"] == "POST") {
    \$domain = escapeshellcmd(\$_POST["domain"]);
    \$web_root = "/var/www/\$domain/public_html";

    if (!file_exists(\$web_root)) {
        mkdir(\$web_root, 0755, true);
        file_put_contents("\$web_root/index.html", "<h1>Welcome to \$domain</h1>");
    }

    \$vhost_config = "
<VirtualHost *:80>
    ServerName \$domain
    DocumentRoot \$web_root
    <Directory \"\$web_root\">
        AllowOverride All
        Require all granted
    </Directory>
    ErrorLog \${APACHE_LOG_DIR}/\$domain-error.log
    CustomLog \${APACHE_LOG_DIR}/\$domain-access.log combined
</VirtualHost>";

    file_put_contents("/etc/apache2/sites-available/\$domain.conf", \$vhost_config);
    shell_exec("a2ensite \$domain.conf && systemctl restart apache2");

    \$message = "Domain \$domain added successfully!";
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <title>Domain Management - AffPanel</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body class="container mt-5">
    <h2>Manage Domains</h2>
    <?php if (isset(\$message)) { echo "<div class='alert alert-success'>\$message</div>"; } ?>
    <form method="post">
        <label>Enter Domain Name:</label>
        <input type="text" name="domain" class="form-control" required>
        <button type="submit" class="btn btn-primary mt-2">Add Domain</button>
    </form>
</body>
</html>
EOF

    chown -R www-data:www-data "$PANEL_DIR"
    chmod -R 755 "$PANEL_DIR"
}

# Function to configure Apache
configure_apache() {
    echo "🔧 Configuring Apache..."
    grep -qxF "Listen 3333" /etc/apache2/ports.conf || echo "Listen 3333" >> /etc/apache2/ports.conf

    cat <<EOF > "$APACHE_CONF"
<VirtualHost *:$PANEL_PORT>
    ServerAdmin admin@localhost
    DocumentRoot "$PANEL_DIR"
    ErrorLog ${APACHE_LOG_DIR}/affpanel-error.log
    CustomLog ${APACHE_LOG_DIR}/affpanel-access.log combined

    <Directory "$PANEL_DIR">
        AllowOverride All
        Require all granted
    </Directory>
</VirtualHost>
EOF

    a2enmod php8.3
    a2ensite affpanel.conf
    systemctl restart apache2
}

# Run all functions
install_dependencies
setup_authentication
setup_panel
configure_apache

echo "✅ Installation complete! Access AffPanel at http://localhost:$PANEL_PORT"
